@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from os.path import dirname
 
 import numpy as np
@@ -7,7 +8,7 @@ from pysme.sme import SME_Structure as SME_Struct
 from pysme.solve import solve
 
 cwd = dirname(__file__)
-filename = "{}/testcase1.inp".format((cwd))
+filename = "{}/testcase1.inp".format(cwd)
 
 
 def test_simple():
